#!/bin/bash
# build.sh - A simon says clone 
# (c) 2010  me@nikosapi.org  GPLv2

set -e # Exit if any command fails

# Compile the code
#  -std=gnu99        The gnu99 standard lets us declare variable in for loops
#  -DF_CPU=1000000   The real clock is 1MHz
#  -mmcu=attiny45    The mcu is an ATtiny45
#  -Os               Enable optimizations  (to reduce resulting binary size)
avr-gcc -std=gnu99 -DF_CPU=1000000 -mmcu=attiny45 -Os simon.c simon.h -o simon

# Extract code and data sections of the resulting binary
avr-objcopy -R .eeprom -O ihex simon simon.hex

# Extract the eeprom data which must be flashed seperately
avr-objcopy -j .eeprom --change-section-lma .eeprom=0 \
    -O ihex simon simon-eeprom.hex

# Flash the microcontroller with the code and the eeprom defaults
avrdude -p t45 -c nbsd -U flash:w:simon.hex -U eeprom:w:simon-eeprom.hex
